@@ -333,45 +333,4 @@ cat("==> to retrieve a design type EEw1s2('EE12R6WP') etc.","\n")
           } else cat(" Design name misspelled-Enter EEw1s2( ) to display list of names","\n")
                  }
 
-EEw1s2( )
-EE <- EEw1s2('EE12R4WP')
-EE <- EEw1s2('EE12R4WP', randomize=TRUE)
-EE <- EEw1s2('EE12R6WP')
-EE <- EEw1s2('EE12R6WP', randomize=TRUE)
-EE <- EEw1s2('EE14R7WP')
-EE <- EEw1s2('EE14R7WP', randomize=TRUE)
-EE <- EEw1s2('EE15R5WP')
-EE <- EEw1s2('EE15R5WP', randomize=TRUE)
-EE <- EEw1s2('EE16R4WP')
-EE <- EEw1s2('EE16R4WP', randomize=TRUE)
-EE <- EEw1s2('EE18R6WP')
-EE <- EEw1s2('EE18R6WP', randomize=TRUE)
-EE <- EEw1s2('EE20R4WP')
-EE <- EEw1s2('EE20R4WP', randomize=TRUE)
-EE <- EEw1s2('EE20R5WP')
-EE <- EEw1s2('EE20R5WP', randomize=TRUE)
-EE <- EEw1s2('EE21R7WP')
-EE <- EEw1s2('EE21R7WP', randomize=TRUE)
-EE <- EEw1s2('EE24R4WP')
-EE <- EEw1s2('EE24R4WP', randomize=TRUE)
-EE <- EEw1s2('EE24R6WP')
-EE <- EEw1s2('EE24R6WP', randomize=TRUE)
-EE <- EEw1s2('EE25R5WP')
-EE <- EEw1s2('EE25R5WP', randomize=TRUE)
-EE <- EEw1s2('EE28R7WP')
-EE <- EEw1s2('EE28R7WP', randomize=TRUE)
-EE <- EEw1s2('EE30R6WP')
-EE <- EEw1s2('EE30R6WP', randomize=TRUE)
-EE <- EEw1s2('EE30R5WP')
-EE <- EEw1s2('EE30R5WP', randomize=TRUE)
-EE <- EEw1s2('EE35R7WP')
-EE <- EEw1s2('EE35R7WP', randomize=TRUE)
-EE <- EEw1s2('EE36R6WP')
-EE <- EEw1s2('EE36R6WP', randomize=TRUE)
-EE <- EEw1s2('EE42R7WP')
-EE <- EEw1s2('EE42R7WP', randomize=TRUE)
-
-
-
-
 
